pub struct RustcContext<'ast, 'tcx> {
    pub rustc_cx: TyCtxt<'tcx>,
    pub lint_store: &'tcx LintStore,
    pub storage: &'ast Storage<'ast>,
    pub marker_converter: MarkerConverter<'ast, 'tcx>,
    pub rustc_converter: RustcConverter<'ast, 'tcx>,
    /* private fields */
}
This is the central context for the rustc driver and the struct providing the callback implementation for MarkerContext.

The struct intentionally only stores the TyCtxt and LintStore and not a LateContext as the late context operates on the assumption that every AST node is only checked in the specific check_ function. This will in contrast convert the entire crate at once and might also jump around inside the AST if a lint crate requests that. This also has the added benefit that we can use the 'tcx lifetime for them.

Fields

rustc_cx: TyCtxt<'tcx>lint_store: &'tcx LintStorestorage: &'ast Storage<'ast>marker_converter: MarkerConverter<'ast, 'tcx>rustc_converter: RustcConverter<'ast, 'tcx>

Implementations

source

impl<'ast, 'tcx> RustcContext<'ast, 'tcx>

source

pub fn new( rustc_cx: TyCtxt<'tcx>, lint_store: &'tcx LintStore, storage: &'ast Storage<'ast> ) -> &'ast Self

source

pub fn ast_cx(&self) -> &'ast MarkerContext<'ast>